@@ -10,7 +10,7 @@ use DBI;
 
 use base qw(Alzabo::Driver);
 
-$VERSION = sprintf '%2d.%02d', q$Revision: 1.36 $ =~ /(\d+)\.(\d+)/;
+$VERSION = sprintf '%2d.%02d', q$Revision: 1.37 $ =~ /(\d+)\.(\d+)/;
 
 1;
 
@@ -35,6 +35,13 @@ sub connect
     $self->{dbh} = $self->_make_dbh(%p, name => $self->{schema}->name);
 }
 
+sub schemas
+{
+    my $self = shift;
+
+    return map { /dbi:\w+:(\w+)/i; defined $1 ? $1 : () } DBI->data_sources( $self->dbi_driver_name );
+}
+
 sub create_database
 {
     my $self = shift;
