@@ -13,7 +13,7 @@ use Time::HiRes qw(time);
 
 use base qw(Alzabo::Table);
 
-$VERSION = sprintf '%2d.%02d', q$Revision: 1.74 $ =~ /(\d+)\.(\d+)/;
+$VERSION = sprintf '%2d.%02d', q$Revision: 1.75 $ =~ /(\d+)\.(\d+)/;
 
 sub insert
 {
@@ -337,30 +337,6 @@ sub _select_sql
     return $sql;
 }
 
-# deprecated
-sub func
-{
-    my $self = shift;
-
-    my %p = @_;
-    validate( @_, { func => { type => SCALAR },
-		    args => { type => SCALAR | ARRAYREF | OBJECT,
-			      optional => 1 },
-		    ( map { $_ => { optional => 1 } } keys %p ) } );
-
-    my $func = uc $p{func};
-    my @args = exists $p{args} ? ( UNIVERSAL::isa( $p{args}, 'ARRAY' ) ? @{ $p{args} } : $p{args} ) : ();
-
-    my $function = $self->schema->sqlmaker->$func(@args);
-
-    my $sql = $self->schema->sqlmaker->select($function)->from($self);
-
-    Alzabo::Runtime::process_where_clause( $sql, $p{where} ) if exists $p{where};
-
-    return $self->schema->driver->one_row( sql => $sql->sql,
-					   bind => $sql->bind );
-}
-
 sub set_prefetch
 {
     my $self = shift;
